@@ -6,7 +6,7 @@ from sqlalchemy.orm import relationship
 
 # Availability class is used, so we must define it here or else it has to be definied by clients of the User class,
 # and they don't necessarily know that they need to do this
-from . import Availability
+from .availability import Availability
 
 
 class User(Base):
